@@ -5,7 +5,7 @@ from webassets import Bundle
 from webassets.env import BaseEnvironment, ConfigStorage
 
 
-__version__ = (0, 2, 2)
+__version__ = (0, 5, '1')
 
 __all__ = ('Environment', 'Bundle',)
 
@@ -50,7 +50,7 @@ class FlaskConfigStorage(ConfigStorage):
             if ctx is not None:
                 return ctx.app
         raise RuntimeError('assets instance not bound to an application, '+
-                           'and no application in current context')
+                            'and no application in current context')
 
     def setdefault(self, key, value):
         """We may not always be connected to an app, but we still need
@@ -102,6 +102,8 @@ class Environment(BaseEnvironment):
 
     def absurl(self, fragment):
         if self.config.get('url') is not None:
+            # If a manual base url is configured, skip any
+            # blueprint-based auto-generation.
             return super(Environment, self).absurl(fragment)
         else:
             try:
@@ -110,15 +112,32 @@ class Environment(BaseEnvironment):
             except (ValueError):
                 filename = fragment
                 query = ''
-            try:
-                module, name = filename.split('/', 1)
-                self.app.modules[module] # generates keyerror if no module
-                endpoint = '%s.static' % module
-                filename = name
-            except (ValueError, KeyError):
-                endpoint = '.static'
-            with self.app.test_request_context():
-                return url_for(endpoint, filename=filename) + query
+
+            if hasattr(self.app, 'blueprints'):
+                try:
+                    blueprint, name = filename.split('/', 1)
+                    self.app.blueprints[blueprint] # generates keyerror if no module
+                    endpoint = '%s.static' % blueprint
+                    filename = name
+                except (ValueError, KeyError):
+                    endpoint = 'static'
+            else:
+                # Module support for Flask < 0.7
+                try:
+                    module, name = filename.split('/', 1)
+                    self.app.modules[module] # generates keyerror if no module
+                    endpoint = '%s.static' % module
+                    filename = name
+                except (ValueError, KeyError):
+                    endpoint = '.static'
+
+            ctx = None
+            if not _request_ctx_stack.top:
+                ctx = self.app.test_request_context()
+                ctx.push()
+            return url_for(endpoint, filename=filename) + query
+            if ctx:
+                ctx.pop()
 
     def abspath(self, filename):
         if path.isabs(filename):
@@ -126,9 +145,15 @@ class Environment(BaseEnvironment):
         if self.config.get('directory') is not None:
             return super(Environment, self).abspath(filename)
         try:
-            module, name = filename.split('/', 1)
-            directory = path.join(self.app.modules[module].root_path, 'static')
-            filename = name
+            if hasattr(self.app, 'blueprints'):
+                blueprint, name = filename.split('/', 1)
+                directory = path.join(self.app.blueprints[blueprint].root_path, 'static')
+                filename = name
+            else:
+                # Module support for Flask < 0.7
+                module, name = filename.split('/', 1)
+                directory = path.join(self.app.modules[module].root_path, 'static')
+                filename = name
         except (ValueError, KeyError):
             directory = path.join(self.app.root_path, 'static')
         return path.abspath(path.join(directory, filename))
